ResponseStatus

Enum ResponseStatus 

pub enum ResponseStatus {
    Ok,
    InvalidUrl,
    InvalidService,
    InvalidVersion,
    InvalidOptions,
    InvalidQuery,
    InvalidValue,
    NoSegment,
    TooBig,
}

Variants



Ok

Request could be processed as expected.



InvalidUrl

URL string is invalid.



InvalidService

Service name is invalid.



InvalidVersion

Version is not found.



InvalidOptions

Options are invalid.



InvalidQuery

The query string is synctactically malformed.



InvalidValue

The successfully parsed query parameters are invalid.



NoSegment

One of the supplied input coordinates could not snap to street segment.



TooBig

The request size violates one of the service specific request size restrictions.